@@ -6,6 +6,8 @@
 ## @author Kathy Le, Sergey Lyskov
 
 
+import sys
+
 def setup(drivepath='/My Drive', install=None):
   if install is not None: #assuming the user installed the .whl version of PyRosetta
     # Mounting Google Drive and add it to Python sys path
@@ -38,7 +40,6 @@ def setup(drivepath='/My Drive', install=None):
       subprocess.check_call([sys.executable, '-m', 'pip', 'install', wheel_path])
 
   else: #assuming the user installed the MinSizeRel version of PyRosetta
-    import sys
     is_colab = 'google.colab' in sys.modules
     if is_colab:
       # Mounting Google Drive and add it to Python sys path
@@ -113,7 +114,17 @@ def execute_through_pty(command_line):
 
 _DEFAULT_PYROSETTA_INSTALL_PREFIX_ = 'PyRosetta/colab.bin'
 
-def mount_pyrosetta_install(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_):
+def check_for_rosetta_so_file(prefix, pyrosetta_package_path):
+    rosetta_so_path = pyrosetta_package_path + f'/pyrosetta/rosetta.so'
+    if os.path.isfile(rosetta_so_path):
+        print(f'PyRosetta installed at {prefix!r}... Please click "Runtime → Restart runtime" before using it.')
+        return False
+    else:
+        print(f'ERROR ERROR ERROR: looks PyRosetta like install procedure has not worked correctly!!!\nERROR ERROR ERROR: Please remove dir {prefix!r} from your Google Drive and then re-run install procedure again!\n\n\n\n')
+        return True
+
+
+def mount_pyrosetta_install(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_, suppres_rosetta_so_check=False):
     if os.getenv("DEBUG"): print('DEBUG mode enable, doing nothing...'); return
 
     google_drive_mount_point = '/content/google_drive'
@@ -132,6 +143,8 @@ def mount_pyrosetta_install(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_):
     from importlib import reload
     reload(site)
 
+    if not suppres_rosetta_so_check: check_for_rosetta_so_file(prefix, pyrosetta_package_path)
+
     return pyrosetta_install_prefix_path, pyrosetta_package_path
 
 
@@ -139,7 +152,7 @@ def mount_pyrosetta_install(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_):
 def install_pyrosetta(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_):
     if os.getenv("DEBUG"): print('DEBUG mode enable, doing nothing...'); return
 
-    pyrosetta_install_prefix_path, pyrosetta_package_path = mount_pyrosetta_install(prefix)
+    pyrosetta_install_prefix_path, pyrosetta_package_path = mount_pyrosetta_install(prefix, suppres_rosetta_so_check=True)
 
     if not os.path.isdir(pyrosetta_install_prefix_path): os.makedirs(pyrosetta_install_prefix_path)
 
@@ -165,8 +178,6 @@ def install_pyrosetta(prefix=_DEFAULT_PYROSETTA_INSTALL_PREFIX_):
     from importlib import reload
     reload(site)
 
-    rosetta_so_path = pyrosetta_package_path + f'/pyrosetta/rosetta.so'
-    if os.path.isfile(rosetta_so_path): print(f'PyRosetta installed at {prefix!r}... Please click "Runtime → Restart runtime" before using it.')
-    else: print(f'ERROR ERROR ERROR: looks like install procedure has not worked correctly, please remove dir {prefix!r} from your Google Drive and then re-run install procedure again!')
+    if check_for_rosetta_so_file(prefix, pyrosetta_package_path): sys.exit(1)
 
     #import pyrosetta
